@@ -118,7 +118,7 @@ QString O2::requestUrl() {
 }
 
 void O2::setRequestUrl(const QString &value) {
-    requestUrl_ = value;
+    requestUrl_ = QUrl(value);
     Q_EMIT requestUrlChanged();
 }
 
@@ -138,7 +138,7 @@ QString O2::tokenUrl() {
 }
 
 void O2::setTokenUrl(const QString &value) {
-    tokenUrl_= value;
+    tokenUrl_= QUrl(value);
     Q_EMIT tokenUrlChanged();
 }
 
@@ -147,7 +147,7 @@ QString O2::refreshTokenUrl() {
 }
 
 void O2::setRefreshTokenUrl(const QString &value) {
-    refreshTokenUrl_ = value;
+    refreshTokenUrl_ = QUrl(value);
     Q_EMIT refreshTokenUrlChanged();
 }
 
